import {
	NavigationMenu,
	NavigationMenuContent,
	NavigationMenuItem,
	NavigationMenuLink,
	NavigationMenuList,
	NavigationMenuTrigger,
} from "@/components/ui/navigation-menu"
import { Link } from "react-router";
import { LucideAlignJustify, LucideCheck, LucideX } from "lucide-react"

import { useState } from "react";
import { z } from "zod";
import { Button } from "./components/ui/button";
import { rootstr } from "./rooturl";

const POST = z.object({
	id: z.number(),
	content: z.string(),
	signing: z.nullable(z.string()),
	post_at: z.coerce.date(),
	phase: z.optional(z.string()),
	enclosure: z.nullable(z.array(z.string()))
})




const Panel = () => {
	const [posts, setPosts] = useState<z.infer<typeof POST>[]>([])
	const [loading, setLoading] = useState(false)
	const load = () => {
		setLoading(true)
		fetch(rootstr + "/api/admin/fetch_post", { credentials: "include" }).then(async val => {
			if ((val.status == 401 || val.status == 400) && await val.text() == "missing or malformvald JWT") {
				window.location.href = "/admin/login"
			} else if (val.status == 200) {
				setPosts((await val.json() as Array<Object>).map(post => POST.parse(post)))
			}
		}).finally(() => { setLoading(false) })
	}

	const verify = (check: boolean, post: number) => {
		fetch(rootstr + "/api/admin/verify_post", { method: "PUT", credentials: "include", body: JSON.stringify({ "post": post, "check": check, }), headers: { "Content-Type": "application/json" } }).then(async e => {
			if (e.status == 200) {
				setPosts(posts.filter(v => v.id != post))
			} else
				if ((e.status == 401 || e.status == 400) && await e.text() == "missing or malformed JWT") {
					window.location.href = "/admin/login"
				} else {
					alert(e.statusText)
				}
		})


	}

	return (<div className="w-full h-dvh bg-stone-700 relative">
		<div className="absolute top-0 right-0 m-3">
			<NavigationMenu>
				<NavigationMenuList>
					<NavigationMenuItem>
						<NavigationMenuTrigger><LucideAlignJustify /> </NavigationMenuTrigger>
						<NavigationMenuContent>
							<NavigationMenuLink asChild>
								<Link to="/admin/panel">Panel</Link>
							</NavigationMenuLink>
							<NavigationMenuLink asChild>
								<Link to="/admin/new_account">New Account</Link>
							</NavigationMenuLink>
						</NavigationMenuContent>
					</NavigationMenuItem>
				</NavigationMenuList>
			</NavigationMenu>
		</div>
		<div className="h-full w-full flex flex-row px-10 pt-20">
			<Button onClick={load} disabled={loading}>Load</Button>
			<div className="grid grid-cols-3 border-3 border-stone-400 rounded w-[80dvw] text-white gap-3 overflow-scroll">
				{posts.length > 0 ? posts.map(post => {
					return (<div key={post.id} className="border rounded h-fit">
						<p>
							{post.content}
						</p>

						<span>id:{post.id}</span>
						<div className="w-full h-50 overflow-scroll flex items-center gap-3">
							{post.enclosure ? post.enclosure.map((e, id) =>
								<img key={id} src={rootstr + "/static/" + e} className="my-auto" />
							) : ""}

						</div>
						<div className="flex flex-row gap-3 ml-2">
							<Button onClick={() => verify(true, post.id)}><LucideCheck /></Button>
							<Button onClick={() => verify(false, post.id)}><LucideX /></Button>

						</div>
					</div>)
				}) : "NULL"}

			</div>
		</div>
	</div>)
}
export default Panel;
