"use client"

import { z } from "zod"

import { zodResolver } from "@hookform/resolvers/zod"
import { useForm } from "react-hook-form"
import {
	Form,
	FormControl,
	FormDescription,
	FormField,
	FormItem,
	FormLabel,
	FormMessage,
} from "@/components/ui/form"
import { Input } from "./components/ui/input"
import { Button } from "./components/ui/button"
import {
	InputOTP,
	InputOTPGroup,
	InputOTPSlot,
} from "@/components/ui/input-otp"
import { useState } from "react"
import {
	Alert,
	AlertDescription,
	AlertTitle,
} from "@/components/ui/alert"
import { AlertCircleIcon } from "lucide-react"
import { rootstr } from "./rooturl"

const formSchema = z.object({
	name: z.string().min(2).max(20),
	password: z.string().min(2).max(40),
	totp_code: z.string()
})

export function LoginForm() {
	const form = useForm<z.infer<typeof formSchema>>({
		resolver: zodResolver(formSchema),
	})
	let [state, updateState] = useState(false)
	let [error, updateError] = useState("")
	function onSubmit(value: z.infer<typeof formSchema>) {
		updateState(true)
		fetch(rootstr + "/api/admin/login", { method: "POST", body: JSON.stringify(value), headers: { "Content-Type": "application/json" }, credentials: 'include' })
			.then(val => {
				console.log(val)
				if (val.status == 401) {
					updateError("登入資訊錯誤")
				} else if (val.status == 200) {
					window.location.href = "/admin/panel"
				}
			}).catch(e => {
				updateError(e)
			})
			.finally(() => {
				setTimeout(() => {
					updateState(false)
				}, 2000)
			})
	}
	return (
		<>
			<Alert variant="destructive" className={error.length > 0 ? "text-left bg-gray-200 mb-2" : "hidden"}>
				<AlertCircleIcon />
				<AlertTitle>無法登入</AlertTitle>
				<AlertDescription>
					<p>{error}</p>
				</AlertDescription>
			</Alert>
			<Form {...form}>
				<form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
					<FormField
						control={form.control}
						name="name"
						render={({ field }) => (
							<FormItem>
								<FormLabel>Username</FormLabel>
								<FormControl>
									<Input placeholder="User Name"  {...field} />
								</FormControl>
								<FormDescription>
									Enter your username.
								</FormDescription>
								<FormMessage />
							</FormItem>
						)}
					/>
					<FormField
						control={form.control}
						name="password"
						render={({ field }) => (
							<FormItem>
								<FormLabel>Password</FormLabel>
								<FormControl>
									<Input placeholder="Password"  {...field} />
								</FormControl>
								<FormDescription>
									Enter your Password.
								</FormDescription>
								<FormMessage />
							</FormItem>
						)}
					/>
					<FormField
						control={form.control}
						name="totp_code"
						render={({ field }) => (
							<FormItem>
								<FormLabel>TOTP Code</FormLabel>
								<FormControl>
									<InputOTP maxLength={6} {...field}>
										<InputOTPGroup>
											<InputOTPSlot index={0} />
											<InputOTPSlot index={1} />
											<InputOTPSlot index={2} />
											<InputOTPSlot index={3} />
											<InputOTPSlot index={4} />
											<InputOTPSlot index={5} />
										</InputOTPGroup>
									</InputOTP>
								</FormControl>
								<FormDescription>
									Enter your TOTP Code.
								</FormDescription>
								<FormMessage />
							</FormItem>
						)}
					/>
					<Button type="submit" disabled={state}>Submit</Button>
				</form>
			</Form>
		</>
	)

}
